"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.spreadDateTime = exports.firehoseTransform = exports.firehoseDrop = void 0;
var _utils = require("../utils");
var _filters = require("../filters");
const firehoseTransform = rule => s => s.filter(onEventType(rule)).tap(_utils.printStartPipeline).filter(onContent(rule)).map(transform(rule)).tap(_utils.printEndPipeline);
exports.firehoseTransform = firehoseTransform;
const firehoseDrop = rules => opt => s => s.filter(uow => !((0, _filters.prefilterOnEventTypes)(rules)(uow) && (0, _filters.prefilterOnContent)(rules)(uow))).tap(_utils.printEndPipeline);
exports.firehoseDrop = firehoseDrop;
const onEventType = rule => (0, _utils.faulty)(uow => (0, _filters.filterOnEventType)(rule, uow));
const onContent = rule => (0, _utils.faulty)(uow => (0, _filters.filterOnContent)(rule, uow));
const spreadDateTime = dt => {
  const date = new Date(dt);
  return {
    year: `${date.getUTCFullYear()}`,
    month: `${date.getUTCMonth() + 1}`.padStart(2, '0'),
    // JavaScript months are 0-indexed
    day: `${date.getUTCDate()}`.padStart(2, '0'),
    hour: `${date.getUTCHours()}`.padStart(2, '0'),
    minute: `${date.getUTCMinutes()}`.padStart(2, '0')
  };
};
exports.spreadDateTime = spreadDateTime;
const metadata = (rule, uow) => rule.metadata ? /* istanbul ignore next */rule.metadata(uow, rule) : {
  partitionKeys: {
    table: rule.tableName,
    ...spreadDateTime(uow.event.timestamp)
  }
};
const transform = rule => (0, _utils.faulty)(uow => {
  const transformed = rule.transform ? rule.transform(uow, rule) : /* istanbul ignore next */{};
  return {
    ...uow,
    transformed,
    result: 'Ok',
    data: Buffer.from(JSON.stringify(transformed), 'utf-8').toString('base64'),
    metadata: metadata(rule, uow)
  };
});